===================
 DoSchema v1.0.0a1
===================

DoSchema v1.0.0a1 was released on October 12, 2016.

About
-----

JSON Schema utility functions and commands.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install doschema==v1.0.0a1

Documentation
-------------

   https://doschema.readthedocs.io/

Happy hacking and thanks for flying DoSchema.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: https://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/doschema
|   URL: http://inveniosoftware.org
